==> SRPAstro-4.7.6.tar.gz: SRPAstro-4.7.6/SRP/__init__.py <==
""" Init file for SRP

Context : SRP
Module  : SRP
Version : 1.3.27
Author  : Stefano Covino
Date    : 16/11/2021
E-mail  : stefano.covino@brera.inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (28/09/2010) First named version.
        : (13/10/2010) V. 3.6.0.
        : (03/11/2010) V. 3.6.1beta.
        : (07/11/2010) V. 3.6.2beta and SRPPipelines.
        : (08/11/2010) V. 3.6.2. Conversion to int for TNG pipeline.
        : (17/11/2010) V. 3.7.0. SRP REM pipeline.
        : (03/12/2010) V. 3.7.1beta.
        : (12/12/2010) V. 3.7.1.
        : (14/12/2010) V. 3.7.2beta
        : (14/12/2010) V. 3.7.2.
        : (15/12/2010) V. 3.7.3beta.
        : (20/12/2010) V. 3.7.3.
        : (26/12/2010) V. 3.8.0beta.
        : (22/02/2011) V. 3.8.0.
        : (23/02/2011) V. 3.8.1beta.
        : (05/03/2011) V. 3.8.1.
        : (05/03/2011) V. 3.8.2beta.
        : (21/03/2011) V. 3.8.2.
        : (27/03/2011) V. 3.8.3beta.
        : (30/03/2011) V. 3.8.3.
        : (30/03/2011) V. 3.8.4beta.
        : (07/04/2011) V. 3.8.4.
        : (08/04/2011) V. 3.8.5beta.
        : (22/04/2011) V. 3.8.5.
        : (25/04/2011) V. 3.8.6beta.
        : (27/04/2011) V. 3.9.0beta.
        : (28/04/2011) V. 3.9.0.
        : (28/04/2011) V. 3.9.1beta.
        : (29/04/2011) V. 3.9.1.
        : (30/04/2011) V. 3.9.2beta.
        : (30/04/2011) V. 3.10.0beta.
        : (13/09/2011) V. 3.10.0.
        : (13/09/2011) V. 3.10.1b1.
        : (22/09/2011) V. 3.10.1b2 and no more SRPPipelines.
        : (29/09/2011) V. 3.10.1b3 and new filters.
        : (02/10/2011) V. 3.10.1b4, general function for list of FITS files.
        : (11/10/2011) V. 3.10.1.
        : (12/10/2011) V. 3.10.2b1.
        : (23/10/2011) V. 3.10.2b2.
        : (30/10/2011) V. 3.10.2.
        : (03/11/2011) V. 3.10.3b1.
        : (04/11/2011) V. 3.10.3b2.
        : (15/11/2011) V. 3.10.3b3.
        : (10/12/2011) V. 3.10.3b4.
        : (16/12/2011) V. 3.10.3.
        : (12/01/2012) V. 3.10.4b1.
        : (12/01/2012) V. 3.10.4b2.
        : (04/02/2012) V. 3.10.4b3.
        : (08/02/2012) V. 3.10.4b4.
        : (14/02/2012) V. 3.10.4b5.
        : (18/02/2012) V. 3.10.4b6 and SRPSky.
        : (28/02/2012) V. 3.10.4.
        : (29/02/2012) V. 3.10.5b1.
        : (05/03/2012) V. 3.10.5b2.
        : (11/03/2012) V. 3.10.5b3.
        : (21/03/2012) V. 3.10.5b4.
        : (20/05/2012) V. 3.10.5b5.
        : (21/05/2012) V. 3.10.5.
        : (27/05/2012) V. 3.10.6b1.
        : (15/06/2012) V. 3.10.6b2.
        : (17/06/2012) V. 3.10.6b3.
        : (31/07/2012) V. 3.10.6b4.
        : (28/08/2012) V. 3.10.6.
        : (31/08/2012) V. 3.10.7b1.
        : (20/09/2012) V. 3.10.7b2.
        : (27/09/2012) V. 3.10.7b3 and SRPTime.
        : (04/12/2012) V. 3.10.7b4.
        : (06/12/2012) V. 3.10.7.
        : (13/12/2012) V. 3.10.8b1.
        : (18/12/2012) V. 3.10.8b2.
        : (20/12/2012) V. 3.10.8b3.
        : (11/02/2013) V. 3.10.8b4.
        : (18/03/2013) V. 3.10.8b5.
        : (20/03/2013) V. 3.10.8b6 and V. 3.10.8
        : (22/03/2013) V. 3.10.9b1.
        : (31/03/2013) V. 3.10.9b2.
        : (03/04/2013) V. 3.10.9b3.
        : (18/04/2013) V. 3.10.9b4.
        : (19/04/2013) V. 3.10.9.
        : (06/05/2013) V. 3.10.10b1.
        : (07/06/2013) V. 3.10.10b2.
        : (26/07/2013) APASS catalogue and V. 3.10.10.b3.
        : (29/07/2013) GetTabEntry returns not identified objects too and V. 3.10.10.b4.
        : (12/08/2013) V. 3.10.10.
        : (13/08/2013) V. 3.10.11b1.
        : (18/08/2013) V. 3.10.11b2.
        : (19/08/2013) V. 3.10.11b3 and b4.
        : (24/08/2013) V. 3.10.11.
        : (26/08/2013) V. 3.10.12b1.
        : (29/08/2013) V. 3.10.12b2 and b3.
        : (30/08/2013) V. 3.10.12b4.
        : (02/09/2013) V. 3.10.12b5.
        : (03/09/2013) V. 3.10.12b6.
        : (16/10/2013) V. 3.10.12b7 and 3.10.12
        : (04/11/2013) V. 3.10.13b1.
        : (15/11/2013) V. 3.10.13b2.
        : (09/01/2014) V. 3.10.13b3.
        : (21/01/2014) V. 3.10.13b4.
        : (28/01/2014) V. 3.10.13b5.
        : (05/02/2014) V. 3.10.13.
        : (06/02/2014) V. 3.10.14 and 3.10.15b1. SRPAstro.FITS management and 3.11.0b1.
        : (25/03/2014) V. 3.11.0.
        : (19/04/2014) V. 3.11.1b1.
        : (04/05/2014) V. 3.11.1b2.
        : (16/07/2014) V. 3.11.1b3.
        : (21/07/2014) V. 3.11.1b4.
        : (02/08/2014) V. 3.12.0b1.
        : (06/08/2014) V. 3.12.0.
        : (27/10/2014) V. 3.12.1b1.
        : (30/10/2014) V. 3.12.1b2.
        : (04/11/2014) V. 3.12.1.
        : (11/11/2014) V. 3.12.2b1.
        : (18/11/2014) V. 3.12.2b2.
        : (19/11/2014) V. 3.12.2b3.
        : (09/12/2014) V. 3.12.2b4.
        : (16/12/2014) V. 3.12.2b5.
        : (22/12/2014) V. 3.12.2 and 3.12.3b1.
        : (12/01/2015) V. 3.12.3b2.
        : (20/01/2015) V. 3.12.3b3.
        : (01/04/2015) V. 3.12.3b4.
        : (22/05/2015) V. 3.12.3b5.
        : (24/07/2015) V. 4.0.0.b1.
        : (29/07/2015) V. 4.0.0.
        : (31/07/2015) V. 4.0.1b1.
        : (27/10/2015) V. 4.0.1b2.
        : (01/11/2015) V. 4.0.1b3.
        : (03/11/2015) V. 4.0.1.
        : (05/11/2015) V. 4.0.2b1.
        : (08/11/2015) V. 4.0.2b2.
        : (09/11/2015) V. 4.0.2.
        : (10/11/2015) V. 4.1.0b1.
        : (11/12/2015) V. 4.1.0b2.
        : (27/01/2016) V. 4.1.0b3.
        : (14/02/2016) V. 4.1.0b4.
        : (17/02/2016) V. 4.1.0b5 and V. 4.1.0.
        : (02/04/2016) V. 4.1.1.
        : (13/06/2016) V. 4.1.2.
        : (16/06/2016) V. 4.1.3b1.
        : (07/07/2016) V. 4.1.3b2.
        : (13/07/2016) V. 4.1.3b3.
        : (19/10/2016) V. 4.1.3.
        : (02/11/2016) V. 4.1.4b1.
        : (05/12/2016) V. 4.1.4b2.
        : (04/01/2017) V. 4.1.4b3 and 4.1.4.
        : (12/01/2017) V. 4.1.5b1.
        : (08/02/2017) V. 4.1.5b2.
        : (14/02/2017) V. 4.1.5b3.
        : (16/02/2017) V. 4.1.5b4.
        : (17/02/2017) V. 4.1.5b5.
        : (21/02/2017) V. 4.2.0.
        : (14/03/2017) V. 4.2.1b1 and 4.2.1.
        : (19/04/2017) V. 4.2.2.
        : (28/04/2017) V. 4.2.3.
        : (29/04/2017) V. 4.2.4.
        : (09/05/2017) V. 4.2.5.
        : (16/05/2017) V. 4.2.6.
        : (18/05/2017) V. 4.2.7.
        : (26/05/2017) V. 4.2.8.
        : (03/07/2017) V. 4.2.9.
        : (22/08/2017) V. 4.2.10.
        : (18/09/2017) V. 4.2.11.
        : (18/10/2017) V. 4.2.12.
        : (19/01/2018) V. 4.3.13.
        : (11/07/2018) V. 4.3.14.
        : (20/08/2018) V. 4.3.15.
        : (17/01/2019) V. 4.3.16.
        : (25/02/2019) V. 4.3.17.
        : (28/04/2019) V. 4.3.18.
        : (13/05/2019) V. 4.4.0.
        : (20/05/2019) V. 4.4.1.
        : (21/08/2019) V. 4.4.2.
        : (04/10/2019) V. 4.4.3.
        : (29/01/2020) V. 4.5.0.
        : (23/04/2020) V. 4.5.1.
        : (12/08/2020) V. 4.6.0.
        : (01/10/2020) V. 4.6.1.
        : (12/05/2021) V. 4.7.0.
        : (19/05/2021) V. 4.7.1b0
        : (20/05/2021) V. 4.7.1
        : (28/05/2021) V. 4.7.2
        : (31/05/2021) V. 4.7.3.
        : (13/07/2021) V. 4.7.4.
        : (12/11/2021) V. 4.7.5.
        : (16/11/2021) V. 4.7.6.
"""



# import
#import pkg_resources


__all__ = ['SRPDatabases', 'SRPCatalogue', 'SRPMath', 'SRPNet',
           'SRPPipelines', 'SRPPlot', 'SRPPolarimetry', 'SRPREM', 
           'SRPSky', 'SRPSpectroscopy', 'SRPSystem', 'SRPTables',
           'SRPTime', 'SRPTNG']


# Version
__version__ = '4.7.6'

#

==> SRPAstro-4.8.1.tar.gz: SRPAstro-4.8.1/SRP/__init__.py <==
""" Init file for SRP

Context : SRP
Module  : SRP
Version : 1.3.29
Author  : Stefano Covino
Date    : 17/01/2023
E-mail  : stefano.covino@inaf.it
URL     : http://www.me.oa-brera.inaf.it/utenti/covino


Usage   : to be imported

Remarks :

History : (28/09/2010) First named version.
        : (13/10/2010) V. 3.6.0.
        : (03/11/2010) V. 3.6.1beta.
        : (07/11/2010) V. 3.6.2beta and SRPPipelines.
        : (08/11/2010) V. 3.6.2. Conversion to int for TNG pipeline.
        : (17/11/2010) V. 3.7.0. SRP REM pipeline.
        : (03/12/2010) V. 3.7.1beta.
        : (12/12/2010) V. 3.7.1.
        : (14/12/2010) V. 3.7.2beta
        : (14/12/2010) V. 3.7.2.
        : (15/12/2010) V. 3.7.3beta.
        : (20/12/2010) V. 3.7.3.
        : (26/12/2010) V. 3.8.0beta.
        : (22/02/2011) V. 3.8.0.
        : (23/02/2011) V. 3.8.1beta.
        : (05/03/2011) V. 3.8.1.
        : (05/03/2011) V. 3.8.2beta.
        : (21/03/2011) V. 3.8.2.
        : (27/03/2011) V. 3.8.3beta.
        : (30/03/2011) V. 3.8.3.
        : (30/03/2011) V. 3.8.4beta.
        : (07/04/2011) V. 3.8.4.
        : (08/04/2011) V. 3.8.5beta.
        : (22/04/2011) V. 3.8.5.
        : (25/04/2011) V. 3.8.6beta.
        : (27/04/2011) V. 3.9.0beta.
        : (28/04/2011) V. 3.9.0.
        : (28/04/2011) V. 3.9.1beta.
        : (29/04/2011) V. 3.9.1.
        : (30/04/2011) V. 3.9.2beta.
        : (30/04/2011) V. 3.10.0beta.
        : (13/09/2011) V. 3.10.0.
        : (13/09/2011) V. 3.10.1b1.
        : (22/09/2011) V. 3.10.1b2 and no more SRPPipelines.
        : (29/09/2011) V. 3.10.1b3 and new filters.
        : (02/10/2011) V. 3.10.1b4, general function for list of FITS files.
        : (11/10/2011) V. 3.10.1.
        : (12/10/2011) V. 3.10.2b1.
        : (23/10/2011) V. 3.10.2b2.
        : (30/10/2011) V. 3.10.2.
        : (03/11/2011) V. 3.10.3b1.
        : (04/11/2011) V. 3.10.3b2.
        : (15/11/2011) V. 3.10.3b3.
        : (10/12/2011) V. 3.10.3b4.
        : (16/12/2011) V. 3.10.3.
        : (12/01/2012) V. 3.10.4b1.
        : (12/01/2012) V. 3.10.4b2.
        : (04/02/2012) V. 3.10.4b3.
        : (08/02/2012) V. 3.10.4b4.
        : (14/02/2012) V. 3.10.4b5.
        : (18/02/2012) V. 3.10.4b6 and SRPSky.
        : (28/02/2012) V. 3.10.4.
        : (29/02/2012) V. 3.10.5b1.
        : (05/03/2012) V. 3.10.5b2.
        : (11/03/2012) V. 3.10.5b3.
        : (21/03/2012) V. 3.10.5b4.
        : (20/05/2012) V. 3.10.5b5.
        : (21/05/2012) V. 3.10.5.
        : (27/05/2012) V. 3.10.6b1.
        : (15/06/2012) V. 3.10.6b2.
        : (17/06/2012) V. 3.10.6b3.
        : (31/07/2012) V. 3.10.6b4.
        : (28/08/2012) V. 3.10.6.
        : (31/08/2012) V. 3.10.7b1.
        : (20/09/2012) V. 3.10.7b2.
        : (27/09/2012) V. 3.10.7b3 and SRPTime.
        : (04/12/2012) V. 3.10.7b4.
        : (06/12/2012) V. 3.10.7.
        : (13/12/2012) V. 3.10.8b1.
        : (18/12/2012) V. 3.10.8b2.
        : (20/12/2012) V. 3.10.8b3.
        : (11/02/2013) V. 3.10.8b4.
        : (18/03/2013) V. 3.10.8b5.
        : (20/03/2013) V. 3.10.8b6 and V. 3.10.8
        : (22/03/2013) V. 3.10.9b1.
        : (31/03/2013) V. 3.10.9b2.
        : (03/04/2013) V. 3.10.9b3.
        : (18/04/2013) V. 3.10.9b4.
        : (19/04/2013) V. 3.10.9.
        : (06/05/2013) V. 3.10.10b1.
        : (07/06/2013) V. 3.10.10b2.
        : (26/07/2013) APASS catalogue and V. 3.10.10.b3.
        : (29/07/2013) GetTabEntry returns not identified objects too and V. 3.10.10.b4.
        : (12/08/2013) V. 3.10.10.
        : (13/08/2013) V. 3.10.11b1.
        : (18/08/2013) V. 3.10.11b2.
        : (19/08/2013) V. 3.10.11b3 and b4.
        : (24/08/2013) V. 3.10.11.
        : (26/08/2013) V. 3.10.12b1.
        : (29/08/2013) V. 3.10.12b2 and b3.
        : (30/08/2013) V. 3.10.12b4.
        : (02/09/2013) V. 3.10.12b5.
        : (03/09/2013) V. 3.10.12b6.
        : (16/10/2013) V. 3.10.12b7 and 3.10.12
        : (04/11/2013) V. 3.10.13b1.
        : (15/11/2013) V. 3.10.13b2.
        : (09/01/2014) V. 3.10.13b3.
        : (21/01/2014) V. 3.10.13b4.
        : (28/01/2014) V. 3.10.13b5.
        : (05/02/2014) V. 3.10.13.
        : (06/02/2014) V. 3.10.14 and 3.10.15b1. SRPAstro.FITS management and 3.11.0b1.
        : (25/03/2014) V. 3.11.0.
        : (19/04/2014) V. 3.11.1b1.
        : (04/05/2014) V. 3.11.1b2.
        : (16/07/2014) V. 3.11.1b3.
        : (21/07/2014) V. 3.11.1b4.
        : (02/08/2014) V. 3.12.0b1.
        : (06/08/2014) V. 3.12.0.
        : (27/10/2014) V. 3.12.1b1.
        : (30/10/2014) V. 3.12.1b2.
        : (04/11/2014) V. 3.12.1.
        : (11/11/2014) V. 3.12.2b1.
        : (18/11/2014) V. 3.12.2b2.
        : (19/11/2014) V. 3.12.2b3.
        : (09/12/2014) V. 3.12.2b4.
        : (16/12/2014) V. 3.12.2b5.
        : (22/12/2014) V. 3.12.2 and 3.12.3b1.
        : (12/01/2015) V. 3.12.3b2.
        : (20/01/2015) V. 3.12.3b3.
        : (01/04/2015) V. 3.12.3b4.
        : (22/05/2015) V. 3.12.3b5.
        : (24/07/2015) V. 4.0.0.b1.
        : (29/07/2015) V. 4.0.0.
        : (31/07/2015) V. 4.0.1b1.
        : (27/10/2015) V. 4.0.1b2.
        : (01/11/2015) V. 4.0.1b3.
        : (03/11/2015) V. 4.0.1.
        : (05/11/2015) V. 4.0.2b1.
        : (08/11/2015) V. 4.0.2b2.
        : (09/11/2015) V. 4.0.2.
        : (10/11/2015) V. 4.1.0b1.
        : (11/12/2015) V. 4.1.0b2.
        : (27/01/2016) V. 4.1.0b3.
        : (14/02/2016) V. 4.1.0b4.
        : (17/02/2016) V. 4.1.0b5 and V. 4.1.0.
        : (02/04/2016) V. 4.1.1.
        : (13/06/2016) V. 4.1.2.
        : (16/06/2016) V. 4.1.3b1.
        : (07/07/2016) V. 4.1.3b2.
        : (13/07/2016) V. 4.1.3b3.
        : (19/10/2016) V. 4.1.3.
        : (02/11/2016) V. 4.1.4b1.
        : (05/12/2016) V. 4.1.4b2.
        : (04/01/2017) V. 4.1.4b3 and 4.1.4.
        : (12/01/2017) V. 4.1.5b1.
        : (08/02/2017) V. 4.1.5b2.
        : (14/02/2017) V. 4.1.5b3.
        : (16/02/2017) V. 4.1.5b4.
        : (17/02/2017) V. 4.1.5b5.
        : (21/02/2017) V. 4.2.0.
        : (14/03/2017) V. 4.2.1b1 and 4.2.1.
        : (19/04/2017) V. 4.2.2.
        : (28/04/2017) V. 4.2.3.
        : (29/04/2017) V. 4.2.4.
        : (09/05/2017) V. 4.2.5.
        : (16/05/2017) V. 4.2.6.
        : (18/05/2017) V. 4.2.7.
        : (26/05/2017) V. 4.2.8.
        : (03/07/2017) V. 4.2.9.
        : (22/08/2017) V. 4.2.10.
        : (18/09/2017) V. 4.2.11.
        : (18/10/2017) V. 4.2.12.
        : (19/01/2018) V. 4.3.13.
        : (11/07/2018) V. 4.3.14.
        : (20/08/2018) V. 4.3.15.
        : (17/01/2019) V. 4.3.16.
        : (25/02/2019) V. 4.3.17.
        : (28/04/2019) V. 4.3.18.
        : (13/05/2019) V. 4.4.0.
        : (20/05/2019) V. 4.4.1.
        : (21/08/2019) V. 4.4.2.
        : (04/10/2019) V. 4.4.3.
        : (29/01/2020) V. 4.5.0.
        : (23/04/2020) V. 4.5.1.
        : (12/08/2020) V. 4.6.0.
        : (01/10/2020) V. 4.6.1.
        : (12/05/2021) V. 4.7.0.
        : (19/05/2021) V. 4.7.1b0
        : (20/05/2021) V. 4.7.1
        : (28/05/2021) V. 4.7.2
        : (31/05/2021) V. 4.7.3.
        : (13/07/2021) V. 4.7.4.
        : (12/11/2021) V. 4.7.5.
        : (16/11/2021) V. 4.7.6.
        : (25/02/2022) V. 4.8.0.
        : (17/01/2023) V. 4.8.1
"""



# import
#import pkg_resources


__all__ = ['SRPDatabases', 'SRPCatalogue', 'SRPMath', 'SRPNet',
           'SRPPipelines', 'SRPPlot', 'SRPPolarimetry', 'SRPREM', 
           'SRPSky', 'SRPSpectroscopy', 'SRPSystem', 'SRPTables',
           'SRPTime', 'SRPTNG']


# Version
__version__ = '4.8.1'

#
